@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Callable, Protocol, runtime_checkable, TypeVar
+from typing import Callable, Protocol, runtime_checkable
 
 from omnipy.api.types import DecoratorClassT
 
@@ -12,11 +12,8 @@ class IsCallableParamAfterSelf(Protocol):
         ...
 
 
-CC = TypeVar('CC', bound=Callable, contravariant=True)
-
-
 @runtime_checkable
-class IsCallableClass(Protocol[DecoratorClassT, CC]):
+class IsCallableClass(Protocol[DecoratorClassT]):
     """"""
-    def __call__(self, *args: object, **kwargs: object) -> Callable[[CC], DecoratorClassT]:
+    def __call__(self, *args: object, **kwargs: object) -> Callable[[Callable], DecoratorClassT]:
         ...
