@@ -1,9 +1,11 @@
 from datetime import datetime
+from typing import Optional
 
-from omnipy.api.protocols import IsNestedContext
+from omnipy.api.protocols.private.compute.mixins import IsNestedContext
 
 
 class FlowContextJobMixin:
+    """"""
     def __init__(self) -> None:
         self._time_of_last_run = None
 
@@ -22,5 +24,5 @@ class FlowContextJobMixin:
         return FlowContext()
 
     @property
-    def time_of_last_run(self) -> datetime:
+    def time_of_last_run(self) -> Optional[datetime]:
         return self._time_of_last_run
