@@ -2,17 +2,14 @@ from dataclasses import dataclass, field
 from typing import Any
 
 from omnipy.api.enums import EngineChoice
-from omnipy.api.protocols import (IsEngine,
-                                  IsEngineConfig,
-                                  IsJobConfig,
-                                  IsJobConfigHolder,
-                                  IsLocalRunnerConfig,
-                                  IsPrefectEngineConfig,
-                                  IsRootLogConfigEntryPublisher,
-                                  IsRootLogObjects,
-                                  IsRunStateRegistry,
-                                  IsRuntimeConfig,
-                                  IsRuntimeObjects)
+from omnipy.api.protocols.private.compute.job_creator import IsJobConfigHolder
+from omnipy.api.protocols.private.engine import IsEngine, IsEngineConfig
+from omnipy.api.protocols.private.log import IsRunStateRegistry
+from omnipy.api.protocols.public.config import (IsJobConfig,
+                                                IsLocalRunnerConfig,
+                                                IsPrefectEngineConfig,
+                                                IsRootLogConfig)
+from omnipy.api.protocols.public.hub import IsRootLogObjects, IsRuntimeConfig, IsRuntimeObjects
 from omnipy.compute.job import JobBase
 from omnipy.config.engine import LocalRunnerConfig, PrefectEngineConfig
 from omnipy.config.job import JobConfig
@@ -37,7 +34,7 @@ class RuntimeConfig(RuntimeEntryPublisher):
     engine: EngineChoice = EngineChoice.LOCAL
     local: IsLocalRunnerConfig = field(default_factory=LocalRunnerConfig)
     prefect: IsPrefectEngineConfig = field(default_factory=PrefectEngineConfig)
-    root_log: IsRootLogConfigEntryPublisher = field(default_factory=RootLogConfigEntryPublisher)
+    root_log: IsRootLogConfig = field(default_factory=RootLogConfigEntryPublisher)
 
 
 @dataclass
