@@ -9,7 +9,7 @@ from omnipy.modules.json.datasets import JsonDataset
 from .functions import encode_api
 
 
-# @mypy_fix_task_template
+@mypy_fix_task_template
 @TaskTemplate()
 def import_dataset_from_encode(endpoints: Iterable[constr(min_length=1)],
                                max_data_item_count: PositiveInt) -> JsonDataset:
